@@ -6,20 +6,18 @@ struct Event {
 struct Runner;
 
 #[async_trait::async_trait]
-impl lambda_runtime_types::Runner<(), Event, ()> for Runner {
-    async fn run<'a>(
+impl<'a> lambda_runtime_types::Runner<'a, (), Event, ()> for Runner {
+    async fn run(
         _shared: &'a (),
-        event: Event,
-        _region: &'a str,
-        _ctx: lambda_runtime_types::Context,
+        event: lambda_runtime_types::LambdaEvent<'a, Event>,
     ) -> anyhow::Result<()> {
-        let timeout_secs = event.timeout_secs.unwrap_or(60);
+        let timeout_secs = event.event.timeout_secs.unwrap_or(60);
         let timeout = tokio::time::Duration::from_secs(timeout_secs);
         tokio::time::sleep(timeout).await;
         Ok(())
     }
 
-    async fn setup() -> anyhow::Result<()> {
+    async fn setup(_region: &'a str) -> anyhow::Result<()> {
         simple_logger::SimpleLogger::new()
             .with_level(log::LevelFilter::Info)
             .init()
